qustop.OptExclude
=================

.. currentmodule:: qustop

.. autoclass:: OptExclude

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OptExclude.__init__
      ~OptExclude.convert_measurements
      ~OptExclude.dual_problem
      ~OptExclude.primal_problem
      ~OptExclude.solve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OptExclude.measurements
      ~OptExclude.value
   
   